summaryrefslogtreecommitdiff
path: root/src/plugins/xfer/xfer-buffer.c
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2011-11-19 11:39:48 +0100
committerSebastien Helleu <flashcode@flashtux.org>2011-11-19 11:39:48 +0100
commit746e56f28c924567d81f98a058735e1909c6758d (patch)
tree34206bc183072d8cc818b87e1fe147f976798306 /src/plugins/xfer/xfer-buffer.c
parent36343a5338097d425c7ada69e37eb81f67512b53 (diff)
downloadweechat-746e56f28c924567d81f98a058735e1909c6758d.zip
xfer: display origin of xfer in core and xfer buffers (task #10956)
Diffstat (limited to 'src/plugins/xfer/xfer-buffer.c')
-rw-r--r--src/plugins/xfer/xfer-buffer.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/plugins/xfer/xfer-buffer.c b/src/plugins/xfer/xfer-buffer.c
index 684406970..f1cbfe592 100644
--- a/src/plugins/xfer/xfer-buffer.c
+++ b/src/plugins/xfer/xfer-buffer.c
@@ -93,9 +93,9 @@ xfer_buffer_refresh (const char *hotlist)
weechat_config_string (xfer_config_color_text),
weechat_config_string (xfer_config_color_text_bg));
/* display first line with remote nick and filename */
weechat_printf_y (xfer_buffer, (line * 2) + 2,
- "%s%s%-24s %s%s%s%s",
+ "%s%s%-24s %s%s%s%s (%s.%s)",
weechat_color(str_color),
(line == xfer_buffer_selected_line) ?
"*** " : " ",
@@ -104,7 +104,9 @@ xfer_buffer_refresh (const char *hotlist)
(XFER_IS_FILE(ptr_xfer->type)) ?
ptr_xfer->filename : _("xfer chat"),
(XFER_IS_FILE(ptr_xfer->type)) ? "\"" : "",
- suffix);
+ suffix,
+ ptr_xfer->plugin_name,
+ ptr_xfer->plugin_id);
snprintf (status, sizeof (status),
"%s", _(xfer_status_string[ptr_xfer->status]));
@@ -93,9 +93,9 @@ xfer_buffer_refresh (const char *hotlist)
weechat_config_string (xfer_config_color_text),
weechat_config_string (xfer_config_color_text_bg));
- /* display first line with remote nick and filename */
+ /* display first line with remote nick, filename and plugin name/id */
weechat_printf_y (xfer_buffer, (line * 2) + 2,